@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 #include "callbacks_mainwindow_menu.h"
 #include "gui_savedialog.h"
+#include "gui_utils.h"
 #include "support.h"
 #include "types.h"
 #include "utils.h"
@@ -48,6 +49,7 @@
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *mainnotebook;
+extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
 extern GList *logwindowlist;
 
@@ -68,7 +70,6 @@ on_menu_log_activate (GtkAction *action, gpointer user_data)
 void
 on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *savedialog;
 	gint i;
 	logtype *logwindow;
 	gboolean logchanged = FALSE;
@@ -81,9 +82,7 @@ on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	if (logchanged)
 		{
-			savedialog = create_savedialog ();
-			gtk_widget_set_sensitive (mainwindow, 0);
-			gtk_widget_show (savedialog);
+			create_savedialog ();
 		}
 	else
 		{
@@ -118,14 +117,12 @@ void
 on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *dateentry, *gmtentry, *callentry, *rstentry, *myrstentry,
-		*remarksentry, *modeentry, *bandentry, *incheckbutton, *outcheckbutton,
+		*remtv, *modeentry, *bandentry, *incheckbutton, *outcheckbutton,
 		*endentry, *powerentry, *nameentry, *qthentry, *locatorentry,
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
 		*qsoframe, *locatorframe, *datebutton, *framelabel;
-	logtype *logwindow;
-	gint i;
-	GtkTreeIter selected;
-	GtkTreeModel *model;
+	GtkTextBuffer *b;
+	gchar *temp;
 
 	dateentry = lookup_widget (mainwindow, "dateentry");
 	gmtentry = lookup_widget (mainwindow, "gmtentry");
@@ -135,7 +132,7 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	modeentry = lookup_widget (mainwindow, "modeentry");
 	rstentry = lookup_widget (mainwindow, "rstentry");
 	myrstentry = lookup_widget (mainwindow, "myrstentry");
-	remarksentry = lookup_widget (mainwindow, "remarksentry");
+	remtv = lookup_widget (mainwindow, "remtv");
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 	incheckbutton = lookup_widget (mainwindow, "incheckbutton");
@@ -147,14 +144,7 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	unknownentry1 = lookup_widget (mainwindow, "unknownentry1");
 	unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
 
-	for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logwindow = g_list_nth_data (logwindowlist, i);
-			if (gtk_tree_selection_get_selected	(gtk_tree_view_get_selection (GTK_TREE_VIEW(logwindow->treeview)), &model, &selected))
-				gtk_tree_selection_unselect_all (gtk_tree_view_get_selection(GTK_TREE_VIEW (logwindow->treeview)));
-		}
-	datebutton = lookup_widget (mainwindow, "datebutton");
-	gtk_widget_grab_focus (datebutton);
+	unselect_logs ();
 
 	gtk_editable_delete_text (GTK_EDITABLE (dateentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (gmtentry), 0, -1);
@@ -164,7 +154,8 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_editable_delete_text (GTK_EDITABLE (bandentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (rstentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (myrstentry), 0, -1);
-	gtk_editable_delete_text (GTK_EDITABLE (remarksentry), 0, -1);
+	b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+	gtk_text_buffer_set_text (b, "", 0);
 	gtk_combo_box_set_active (GTK_COMBO_BOX(modeoptionmenu), 0);
 	gtk_combo_box_set_active (GTK_COMBO_BOX(bandoptionmenu), 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (outcheckbutton), FALSE);
@@ -178,7 +169,9 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	qsoframe = lookup_widget (mainwindow, "qsoframe");
 	framelabel = gtk_frame_get_label_widget (GTK_FRAME(qsoframe));
-	gtk_label_set_text (GTK_LABEL (framelabel), _("New QSO"));
+	temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
+	gtk_label_set_markup (GTK_LABEL (framelabel), temp);
+	g_free (temp);
 
 	locatorframe = lookup_widget (mainwindow, "locatorframe");
 	if (GTK_WIDGET_VISIBLE (locatorframe))
@@ -187,6 +180,13 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 			framelabel = gtk_frame_get_label_widget (GTK_FRAME(locatorframe));
 			gtk_label_set_text (GTK_LABEL (framelabel), _("Locator"));
 		}
+	if (keyerwindow)
+		gtk_widget_grab_focus (callentry);
+	else
+	{
+		datebutton = lookup_widget (mainwindow, "datebutton");
+		gtk_widget_grab_focus (datebutton);
+	}
 }
 
 /* click all buttons when hamlib enabled, fill in defaults */
@@ -195,8 +195,11 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *datebutton, *gmtbutton, *endbutton, *endhbox,
 		*myrstentry, *unknown1hbox, *unknown2hbox, *unknownentry1, *unknownentry2,
-		*remarksvbox, *remarksentry, *bandentry, *modeentry, *rstentry, *powerhbox, 
-		*powerentry, *endentry, *callentry;
+		*remarksvbox, *remtv, *bandentry, *modeentry, *rstentry, *powerhbox, 
+		*powerentry, *endentry, *callentry, *count;
+	GtkTextBuffer *b;
+	gint c;
+	gchar *countstr, *str;
 #if WANT_HAMLIB
 	GtkWidget *mhzbutton, *modebutton, *rstbutton, *powerbutton;
 #endif
@@ -223,34 +226,35 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	powerentry = lookup_widget (mainwindow, "powerentry");
 #if WANT_HAMLIB
 	if (preferences.hamlib > 0)
-		{ /* when polling use state struct else retrieve info from
-			the rig one by one */
-			if (preferences.polltime == 0) get_riginfo();
-			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1)) == 0)
+	{ /* when polling use state struct else retrieve info from
+		the rig one by one */
+		if (preferences.polltime == 0) get_riginfo();
+		if (preferences.bandseditbox == 0 ||
+	strlen(gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1)) == 0)
+		{
+			mhzbutton = lookup_widget (mainwindow, "mhzbutton");
+			g_signal_emit_by_name (G_OBJECT (mhzbutton), "clicked");
+		}
+		if (preferences.modeseditbox == 0 ||
+	strlen(gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1)) == 0)
+		{
+			modebutton = lookup_widget (mainwindow, "modebutton");
+			g_signal_emit_by_name (G_OBJECT (modebutton), "clicked");
+		}
+		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (rstentry), 0, -1)) == 0)
+		{
+			rstbutton = lookup_widget (mainwindow, "rstbutton");
+			g_signal_emit_by_name (G_OBJECT (rstbutton), "clicked");
+		}
+		if (GTK_WIDGET_VISIBLE (powerhbox))
+		{
+			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
 			{
-				mhzbutton = lookup_widget (mainwindow, "mhzbutton");
-				g_signal_emit_by_name (G_OBJECT (mhzbutton), "clicked");
-			}
-			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1)) == 0)
-			{
-				modebutton = lookup_widget (mainwindow, "modebutton");
-				g_signal_emit_by_name (G_OBJECT (modebutton), "clicked");
-			}
-			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (rstentry), 0, -1)) == 0)
-			{
-				rstbutton = lookup_widget (mainwindow, "rstbutton");
-				g_signal_emit_by_name (G_OBJECT (rstbutton), "clicked");
-			}
-			if (GTK_WIDGET_VISIBLE (powerhbox))
-			{
-				if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) 
-					== 0)
-				{
-					powerbutton = lookup_widget (mainwindow, "powerbutton");
-					g_signal_emit_by_name (G_OBJECT (powerbutton), "clicked");
-				}
+				powerbutton = lookup_widget (mainwindow, "powerbutton");
+				g_signal_emit_by_name (G_OBJECT (powerbutton), "clicked");
 			}
 		}
+	}
 	else
 	{
 		if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
@@ -261,7 +265,25 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_entry_set_text (GTK_ENTRY (modeentry), preferences.defaultmode);
 		if (g_ascii_strcasecmp (preferences.defaulttxrst, "?"))
 			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (rstentry), 0, -1)) == 0)
-				gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
+			{
+				if (keyerwindow && g_strrstr (preferences.defaulttxrst, "#"))
+				{
+					count = lookup_widget (keyerwindow, "count");
+					c = gtk_spin_button_get_value (GTK_SPIN_BUTTON(count));
+					if (c < 10)
+						countstr = g_strdup_printf ("00%d", c);
+					else if (c < 100)
+						countstr = g_strdup_printf ("0%d", c);
+					else
+						countstr = g_strdup_printf ("%d", c);
+					str = my_strreplace (preferences.defaulttxrst, "#", countstr);
+					g_free (countstr);
+					gtk_entry_set_text (GTK_ENTRY (rstentry), str);
+					g_free (str);
+				}
+				else
+					gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
+			}
 		if (GTK_WIDGET_VISIBLE (powerhbox) && g_ascii_strcasecmp (preferences.defaultpower, "?"))
 		{
 			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
@@ -278,7 +300,25 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_entry_set_text (GTK_ENTRY (modeentry), preferences.defaultmode);
 	if (g_ascii_strcasecmp (preferences.defaulttxrst, "?"))
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (rstentry), 0, -1)) == 0)
-			gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
+		{
+			if (keyerwindow && g_strrstr (preferences.defaulttxrst, "#"))
+			{
+				count = lookup_widget (keyerwindow, "count");
+				c = gtk_spin_button_get_value (GTK_SPIN_BUTTON(count));
+				if (c < 10)
+					countstr = g_strdup_printf ("00%d", c);
+				else if (c < 100)
+					countstr = g_strdup_printf ("0%d", c);
+				else
+					countstr = g_strdup_printf ("%d", c);
+				str = my_strreplace (preferences.defaulttxrst, "#", countstr);
+				g_free (countstr);
+				gtk_entry_set_text (GTK_ENTRY (rstentry), str);
+				g_free (str);
+			}
+			else
+				gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
+		}
 	if (GTK_WIDGET_VISIBLE (powerhbox) && g_ascii_strcasecmp (preferences.defaultpower, "?"))
 	{
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
@@ -310,12 +350,17 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	remarksvbox = lookup_widget (mainwindow, "remarksvbox");
 	if (GTK_WIDGET_VISIBLE (remarksvbox) && g_ascii_strcasecmp (preferences.defaultremarks, "?"))
 	{
-		remarksentry = lookup_widget (mainwindow, "remarksentry");
-		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (remarksentry), 0, -1)) == 0)
-			gtk_entry_set_text (GTK_ENTRY (remarksentry),	preferences.defaultremarks);
+		remtv = lookup_widget (mainwindow, "remtv");
+		b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+		if (gtk_text_buffer_get_char_count(GTK_TEXT_BUFFER(b)) == 0)
+			gtk_text_buffer_set_text (b, preferences.defaultremarks, -1);
 	}
+
+	unselect_logs ();
+
 	callentry = lookup_widget (mainwindow, "callentry");
 	gtk_widget_grab_focus (callentry);
+	gtk_editable_set_position (GTK_EDITABLE(callentry), -1);
 }
 
 /* show/hide the toolbar */
@@ -374,8 +419,7 @@ sort_by_date_time (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer
 }
 
 void
-on_sort_log_activate                   (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+on_sort_log_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	logtype *logw;
 	gint page;
