@@ -112,12 +112,14 @@ on_callentry_insert_text (GtkEditable * editable, gchar * new_text,
 	gchar *result = g_new (gchar, new_text_length);
 
 	for (i = 0; i < new_text_length; i++)
-		result[i] = islower (new_text[i]) ? toupper (new_text[i]) : new_text[i];
+result[i] = islower (new_text[i]) ? toupper (new_text[i]) : new_text[i];
 
-	/* insert the new callsign and block insert_text, so we don't call this twice */
-	g_signal_handlers_block_by_func (GTK_OBJECT (editable),	on_callentry_insert_text, user_data);
+/* insert the new callsign and block insert_text, so we don't call this twice */
+	g_signal_handlers_block_by_func
+		(GTK_OBJECT (editable),	on_callentry_insert_text, user_data);
 	gtk_editable_insert_text (editable, result, new_text_length, position);
-	g_signal_handlers_unblock_by_func (GTK_OBJECT (editable),	on_callentry_insert_text, user_data);
+	g_signal_handlers_unblock_by_func
+		(GTK_OBJECT (editable), on_callentry_insert_text, user_data);
 	g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text"); 
 	g_free (result);
 }
@@ -125,8 +127,9 @@ on_callentry_insert_text (GtkEditable * editable, gchar * new_text,
 static void
 updateb4dialog_and_typeaheadfind (gchar * callsign)
 {
-	GtkWidget *b4treeview, *remarksvbox, *remarksentry, *namehbox, *nameentry,
+	GtkWidget *b4treeview, *remarksvbox, *remtv, *namehbox, *nameentry,
 		*qthhbox, *qthentry, *locatorhbox, *locatorentry;
+	GtkTextBuffer *b;
 	guint i, j;
 	logtype *logw;
 	gchar *logcallsign, **b4 = NULL, *temp, *entry;
@@ -150,7 +153,8 @@ updateb4dialog_and_typeaheadfind (gchar * callsign)
 	}
 
 	/* search all logs, if there is a match display it */
-	if ((b4dialog && GTK_WIDGET_VISIBLE (b4dialog))|| (preferences.typeaheadfind == 1))
+	if ((b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		|| (preferences.typeaheadfind == 1))
 	{
 		for (i = 0; i < g_list_length (logwindowlist); i++)
 		{
@@ -160,13 +164,16 @@ updateb4dialog_and_typeaheadfind (gchar * callsign)
 			while (valid)
 			{
 				gtk_tree_model_get (model, &iter, CALL, &logcallsign, -1);
-				if ((preferences.typeaheadfind == 1) && !found && !g_ascii_strcasecmp (callsign, logcallsign))
+				if ((preferences.typeaheadfind == 1)
+					&& !found
+					&& !g_ascii_strcasecmp (callsign, logcallsign))
 				{ /* type ahead find */
 					namehbox = lookup_widget(mainwindow, "namehbox");
 					if (GTK_WIDGET_VISIBLE (namehbox))
 					{
 						nameentry = lookup_widget(mainwindow, "nameentry");
-						entry = gtk_editable_get_chars (GTK_EDITABLE (nameentry), 0, -1);
+						entry = gtk_editable_get_chars
+							(GTK_EDITABLE (nameentry), 0, -1);
 						if (strlen (entry) == 0)
 						{
 							gtk_tree_model_get (model, &iter, NAME, &temp, -1);
@@ -178,7 +185,8 @@ updateb4dialog_and_typeaheadfind (gchar * callsign)
 					if (GTK_WIDGET_VISIBLE (qthhbox))
 					{
 						qthentry = lookup_widget(mainwindow, "qthentry");
-						entry = gtk_editable_get_chars (GTK_EDITABLE (qthentry), 0, -1);
+						entry = gtk_editable_get_chars
+							(GTK_EDITABLE (qthentry), 0, -1);
 						if (strlen (entry) == 0)
 						{
 							gtk_tree_model_get (model, &iter, QTH, &temp, -1);
@@ -190,7 +198,8 @@ updateb4dialog_and_typeaheadfind (gchar * callsign)
 					if (GTK_WIDGET_VISIBLE (locatorhbox))
 					{
 						locatorentry = lookup_widget(mainwindow, "locatorentry");
-						entry = gtk_editable_get_chars (GTK_EDITABLE (locatorentry), 0, -1);
+						entry = gtk_editable_get_chars
+							(GTK_EDITABLE (locatorentry), 0, -1);
 						if (strlen (entry) == 0)
 						{
  							gtk_tree_model_get (model, &iter, LOCATOR, &temp, -1);
@@ -199,33 +208,37 @@ updateb4dialog_and_typeaheadfind (gchar * callsign)
 						g_free (entry);
 					}
 					remarksvbox = lookup_widget(mainwindow, "remarksvbox");
-					if (!g_ascii_strcasecmp (preferences.defaultremarks, "?") && GTK_WIDGET_VISIBLE (remarksvbox))
+					if (!g_ascii_strcasecmp (preferences.defaultremarks, "?")
+						&& GTK_WIDGET_VISIBLE (remarksvbox))
 					{
-						remarksentry = lookup_widget(mainwindow, "remarksentry");
-						entry = gtk_editable_get_chars (GTK_EDITABLE (remarksentry), 0, -1);
-						if (strlen (entry) == 0)
+						remtv = lookup_widget(mainwindow, "remtv");
+						b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+						if (gtk_text_buffer_get_char_count
+							(GTK_TEXT_BUFFER(b)) == 0)
 						{
-							gtk_tree_model_get (model, &iter, REMARKS, &temp, -1);
-							gtk_entry_set_text (GTK_ENTRY (remarksentry), temp);
+							gtk_tree_model_get
+								(model, &iter, REMARKS, &temp, -1);
+							gtk_text_buffer_set_text (b, temp, -1);
 						}
-						g_free (entry);
 					}
 					found = TRUE; /* lookup only once */
 				}
- 				if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog) && !g_ascii_strncasecmp (callsign, logcallsign, strlen (callsign)))
+ 				if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog) && 
+			!g_ascii_strncasecmp (callsign, logcallsign, strlen (callsign)))
 				{	/* worked b4 */
 					b4[0] = g_strdup (logw->logname);
 					for (j = 0; j < QSO_FIELDS; j++)
 					{
-						column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), j);
-						if (gtk_tree_view_column_get_visible (column))
-							gtk_tree_model_get (model, &iter, j, &b4[j+1], -1);
-						else b4[j+1] = g_strdup("");
+						column = gtk_tree_view_get_column
+							(GTK_TREE_VIEW(logw->treeview), j);
+						gtk_tree_model_get (model, &iter, j, &b4[j+1], -1);
 					}
-					gtk_tree_store_prepend (GTK_TREE_STORE(b4model), &b4iter, NULL);
+					gtk_tree_store_prepend
+						(GTK_TREE_STORE(b4model), &b4iter, NULL);
 					for (j = 0; j < QSO_FIELDS + 1; j++)
 					if (strlen(b4[j]) > 0) /* for responsiveness */
-						gtk_tree_store_set (GTK_TREE_STORE(b4model), &b4iter, j, b4[j], -1);
+						gtk_tree_store_set
+							(GTK_TREE_STORE(b4model), &b4iter, j, b4[j], -1);
 				}
 				valid = gtk_tree_model_iter_next (model, &iter);
 			}
@@ -260,13 +273,15 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 	{
 		if ((state.shmid = shmget (KEY, SHMSIZE, IPC_CREAT | 0600)) < 0)
 		{
-			errorstr = g_strdup_printf (_("shmget failed: %s"), g_strerror (errno));
+			errorstr = g_strdup_printf
+				(_("shmget failed: %s"), g_strerror (errno));
 			update_statusbar (errorstr);
 			g_free (errorstr);
 		}
 		if ((shareCall = (shmat (state.shmid, NULL, 0))) == (gchar *) - 1)
 		{
-			errorstr = g_strdup_printf (_("shmat failed: %s"), g_strerror (errno));
+			errorstr = g_strdup_printf
+				(_("shmat failed: %s"), g_strerror (errno));
 			update_statusbar (errorstr);
 			g_free (errorstr);
 			state.shmid = -1;
@@ -466,3 +481,19 @@ on_locatorentry_changed (GtkEditable * editable, gpointer user_data)
 	updatelocatorframe (locator);
 	g_free (locator);
 }
+
+void
+tv_changed (GtkTextBuffer *buffer, gpointer user_data)
+{
+	gint count;
+	GtkTextIter start, end;
+
+	count = gtk_text_buffer_get_char_count (buffer);
+	if (count > 512)
+	{
+		update_statusbar (_("Warning, remarks line to long!!"));
+		gdk_beep ();
+	}
+	gtk_text_buffer_get_bounds (buffer, &start, &end);
+	gtk_text_buffer_apply_tag_by_name (buffer, "tiny", &start, &end);
+}
