@@ -29,6 +29,7 @@
 extern preferencestype preferences;
 extern GtkWidget *mainwindow;
 
+#if GTK_MAJOR_VERSION > 1 && GTK_MINOR_VERSION > 5
 static void
 handle_url (GtkAboutDialog *about, const char *link, gpointer data)
 {
@@ -50,12 +51,12 @@ handle_email (GtkAboutDialog *about, const char *link, gpointer data)
 		(NULL, command, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
 	g_free (command[1]);
 }
+#endif
 
 void
 on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	if (gtk_major_version > 1 && gtk_minor_version > 5)
-	{
+#if GTK_MAJOR_VERSION > 1 && GTK_MINOR_VERSION > 5
 		gchar *authors[] = { "Joop Stakenborg PG4I <pg4i@amsat.org>", 
 			"Stephane Fillod F8CFE <f8cfe@free.fr>", NULL };
 		GdkPixbuf *pixbuf = create_pixbuf ("xlog.png");
@@ -88,14 +89,12 @@ on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 "Danish: Alexandru Csete OZ9AEC <alexc@phys.au.dk>\n"
 "Dutch: Joop Stakenborg PG4I <pg4i@amsat.org>\n"
 "French: Jean-Luc Coulon F5IBH <jean-luc.coulon@wanadoo.fr>\n"
-"Polish: Boguslaw Ciastek SQ5TB <sq5tb@op.pl>\n"
+"Polish: Boguslaw Ciastek SQ5TB <ciacho@z.pl>\n"
 "Spanish: Jaime Robles EA4TV <jaime@robles.nu>\n"
 "Slovak: Michal Karas OM4AA <zoliq@ilm.utc.sk>\n",
 			"version", VERSION,
 			NULL);
-	}
-	else
-	{
+#else
 		GtkWidget *aboutdialog, *aboutlabel1, *aboutlabel2, *aboutlabel3,
 			*aboutlabel4, *vbox, *image;
 		gchar *labeltext, *text1, *text2;
@@ -148,5 +147,5 @@ on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_show_all (aboutdialog);
 		response = gtk_dialog_run (GTK_DIALOG (aboutdialog));
 		gtk_widget_destroy (aboutdialog);
-	}
+#endif
 }
