@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ extern GtkWidget *mainnotebook;
 extern GtkWidget *mainwindow;
 extern preferencestype preferences;
 extern statetype state;
+extern GtkUIManager *ui_manager;
 
 /* check for correct characters */
 static void
@@ -61,6 +62,8 @@ on_newlogentry_changed (GtkEditable * editable, gpointer user_data)
 				case '0' ... '9':
 				case 'a' ... 'z':
 				case 'A' ... 'Z':
+				case '-':
+				case '_':
 					break;
 				default:
 					gdk_beep ();
@@ -75,9 +78,7 @@ on_newlogentry_changed (GtkEditable * editable, gpointer user_data)
 void
 on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *newlogdialog, *dialog_vbox, *vbox, *label1, *hbox, *label2,
-		*newlogentry, *dialog_action_area, *newlogcancelbutton, *newlogokbutton;
-	GdkPixbuf *newlogdialog_icon_pixbuf;
+	GtkWidget *newlogdialog, *vbox, *label, *newlogentry, *clearmenu;
 	gchar *entry, *filename, *xlogbackupfile;
 	logtype *logwindow = NULL;
 	gint i, response;
@@ -85,61 +86,26 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gboolean logopen = FALSE, logexist = FALSE;
 	GString *logs;
 
-	newlogdialog = gtk_dialog_new ();
-	gtk_window_set_title (GTK_WINDOW (newlogdialog), _("xlog - new log"));
-	gtk_window_set_position (GTK_WINDOW (newlogdialog), GTK_WIN_POS_MOUSE);
-	newlogdialog_icon_pixbuf = create_pixbuf ("xlog.png");
-	if (newlogdialog_icon_pixbuf)
-		{
-			gtk_window_set_icon (GTK_WINDOW (newlogdialog), newlogdialog_icon_pixbuf);
-			g_object_unref (newlogdialog_icon_pixbuf);
-		}
-
-	dialog_vbox = GTK_DIALOG (newlogdialog)->vbox;
-	gtk_widget_show (dialog_vbox);
-
-	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox), vbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-
-	label1 = gtk_label_new (_("Enter a name for this log"));
-	gtk_widget_show (label1);
-	gtk_box_pack_start (GTK_BOX (vbox), label1, TRUE, TRUE, 0);
-	gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_CENTER);
-	gtk_label_set_line_wrap (GTK_LABEL (label1), TRUE);
-
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
-
-	label2 = gtk_label_new_with_mnemonic ("(a-z, A-Z, 0-9)");
-	gtk_widget_show (label2);
-	gtk_box_pack_start (GTK_BOX (hbox), label2, TRUE, TRUE, 0);
-	gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_CENTER);
-	gtk_label_set_line_wrap (GTK_LABEL (label2), TRUE);
-
+	newlogdialog = gtk_dialog_new_with_buttons (_("xlog - new log"),
+		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_add
+		(GTK_CONTAINER (GTK_DIALOG (newlogdialog)->vbox), vbox);
+	label = gtk_label_new
+(_("Enter a name for this log (a-z, A-Z, 0-9, dash(-) and underscore(_))"));
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	newlogentry = gtk_entry_new ();
-	gtk_widget_show (newlogentry);
 	gtk_box_pack_start (GTK_BOX (vbox), newlogentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (newlogentry), 15);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
 
-	dialog_action_area = GTK_DIALOG (newlogdialog)->action_area;
-	gtk_widget_show (dialog_action_area);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_SPREAD);
-
-	newlogcancelbutton = gtk_button_new_from_stock ("gtk-cancel");
-	gtk_widget_show (newlogcancelbutton);
-	gtk_dialog_add_action_widget (GTK_DIALOG (newlogdialog), newlogcancelbutton, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS (newlogcancelbutton, GTK_CAN_DEFAULT);
-
-	newlogokbutton = gtk_button_new_from_stock ("gtk-ok");
-	gtk_widget_show (newlogokbutton);
-	gtk_dialog_add_action_widget (GTK_DIALOG (newlogdialog), newlogokbutton, GTK_RESPONSE_OK);
-	GTK_WIDGET_SET_FLAGS (newlogokbutton, GTK_CAN_DEFAULT);
-
-	g_signal_connect ((gpointer) newlogentry, "changed", G_CALLBACK (on_newlogentry_changed), NULL);
+	g_signal_connect ((gpointer) newlogentry, "changed",
+		G_CALLBACK (on_newlogentry_changed), NULL);
 
+	gtk_widget_show_all (newlogdialog);
 	response = gtk_dialog_run (GTK_DIALOG (newlogdialog));
 	state.utf8error = FALSE;
 	if (response == GTK_RESPONSE_OK)
@@ -162,7 +128,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 			}
 			if (!logopen)
 			{		/* check if the log exists and open it */
-				filename = g_strconcat (entry, ".xlog", 0);
+				filename = g_strconcat (entry, ".xlog", NULL);
 				logs = getlogs (preferences.savedir, "*");
 				if (((logs->len) > 0) && (g_strrstr (logs->str, filename)))
 				{
@@ -200,6 +166,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 					gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
 					set_qsoframe (logwindow);
 					set_tabs_menu ();
+					set_font (preferences.logfont);
 				}	
 				g_free (filename);
 			}
@@ -210,7 +177,9 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_widget_destroy (newlogdialog);
 			return;
 		}
-		on_clearframe_activate (NULL, NULL);
+		clearmenu = gtk_ui_manager_get_widget
+			(ui_manager, "/MainMenu/EditMenu/Clear All");
+		g_signal_emit_by_name (G_OBJECT (clearmenu), "activate");
 		gtk_widget_destroy (newlogdialog);
 
 		if (logexist && state.utf8error) 
@@ -218,7 +187,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 				_("There were some errors converting from your locale to UTF8, "
 				"which is used by GTK+ internally. It is best if you start xlog "
 				"from a terminal and see what the errors are. Please check your "
-				"language settings and your log fields!"));
+				"language settings and your log fields!"), "gtk-dialog-warning");
 
 		/* now fire up the logeditor */
 		if ((!logopen) && (!logexist))
