@@ -28,7 +28,7 @@
 
 #include "logfile.h"
 #include "types.h"
-
+#include "wwl.h"
 
 /*
  * file fields
@@ -95,6 +95,7 @@ gint
 labels_qso_append (LOGDB * handle, const qso_t * q)
 {
 	FILE *fp = (FILE *) handle->priv;
+	gint kms, miles, l, result;
 
 	if (preferences.saveastsv[0] == '1')
 	{
@@ -150,7 +151,34 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 	}
 	if (preferences.saveastsv[26] == '1')
 	{
-		if (q[LOCATOR]) fprintf (fp, "%s\t", q[LOCATOR]); else fprintf (fp, "\t");
+		if (q[LOCATOR])
+		{
+			if (preferences.tsvcalc == 0) 
+				fprintf (fp, "%s\t", q[LOCATOR]);
+			else
+			{
+				result =  wwl (preferences.locator, q[LOCATOR], &kms, &l);
+				if (result == 1)
+				{
+					if (preferences.units == 1)
+						fprintf (fp, "%s\t%d\t%d\t", q[LOCATOR], kms, l);
+					else
+					{
+						miles = (gint) (kms / 1.609);
+						fprintf (fp, "%s\t%d\t%d\t", q[LOCATOR], miles, l);
+					}
+				}
+				else
+					fprintf (fp, "%s\t%d\t%d\t", q[LOCATOR], 0, 0);
+			}
+ 		}
+		else 
+		{
+			if (preferences.tsvcalc == 0) 
+				fprintf (fp, "\t");
+			else
+				fprintf (fp, "\t\t\t");
+		}
 	}
 	if (preferences.saveastsv[28] == '1')
 	{
