@@ -37,9 +37,9 @@
 #include <sys/msg.h>
 #endif
 
-#if WANT_HAMLIB
-# include <hamlib/rig.h>
-# include "hamlib-utils.h"
+#if defined(WANT_HAMLIB)
+#include <hamlib/rig.h>
+#include "hamlib-utils.h"
 #endif
 
 #include "gui_b4dialog.h"
@@ -147,7 +147,6 @@ static void
 setdefaultstate (void)
 {
 	state.qsos = 0;
-	state.countries = 0;
 	/* the default ham lives in the gulf of guinea */
 	state.mylocation = g_strdup ("0.0N0.0E");
 	state.controlkey = FALSE;
@@ -181,15 +180,13 @@ check_gtk_version (void)
 gint
 main (int argc, char *argv[])
 {
-	GtkWidget *bandoptionmenu, *modeoptionmenu, *dateentry, *qsoframe,
-		*dxccframe, *bandentry, *modeentry, *clocklabel,
-		*clockhandlebox, *mhzlabel, *mhzbutton,
+	GtkWidget *bandoptionmenu, *modeoptionmenu, *dateentry,
+		*bandentry, *modeentry,	*clockhandlebox, *mhzlabel, *mhzbutton,
 		*frequencylabel, *frequencyhandlebox, *modelabel, *modebutton,
 		*rstlabel, *rstbutton, *smeterhandlebox, *smeterdrawingarea,
-		*hpaned, *powerlabel, *powerbutton, *locatorframe, *unknownlabel1,
-		*unknownlabel2, *handlebox;
+		*hpaned, *powerlabel, *powerbutton, *unknownlabel1,	*unknownlabel2, *handlebox;
 	gchar *xlogfile, *xlogbackupfile, *temp, *logstoload, **loglist = NULL;
-	gint i, j, ctyresult;
+	gint i, j, result;
 	gboolean showmainwindow = TRUE, logsfromprefs = FALSE, gtk_mismatch = FALSE;
 	logtype *logwindow = NULL;
 	LOGDB *lp = NULL;
@@ -233,10 +230,9 @@ main (int argc, char *argv[])
 	remote.nr = 0;
 	remote.program = g_strdup ("unknown");
 
-	ctyresult = readctydata ();
-	if (ctyresult)
-		g_warning (_("Could not read cty.dat"));
-	ctyresult = readxlogdata ();
+	result = readctydata ();
+	if (result)
+		g_warning (_("Could not read dxcc table"));
 
 	qso = g_new0 (gchar *, QSO_FIELDS);
 	for (i = 0; i < QSO_FIELDS; i++)
@@ -328,10 +324,16 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (mainnotebook), "switch_page",
 					G_CALLBACK (on_mainnotebook_switch_page), NULL);
 
+	/* set the menu strings for the bandoption menu */
+	makebandoptionmenu (preferences.bands);
+	/* set the menu strings for the modeoption menu */
+	makemodeoptionmenu (preferences.modes);
+
 	/* first page has focus */
 	if (lp && i > 0)
 		logwindow = g_list_nth_data (logwindowlist, 0);
 	set_qsoframe (logwindow);
+	set_font (preferences.logfont);
 
 	/* we have to set the labels of the unknown fields, 
 		wether they are visible or not */
@@ -341,16 +343,9 @@ main (int argc, char *argv[])
 	gtk_label_set_text (GTK_LABEL (unknownlabel2), preferences.freefield2);
 
 	/* update the statusbar with some information */
-	temp = g_strdup_printf (_("%d QSO's and %d countries loaded"),
-				state.qsos, state.countries);
+	temp = g_strdup_printf (_("%d QSO's loaded"), state.qsos);
 	update_statusbar (temp);
 
-	/* set the menu strings for the bandoption menu */
-	makebandoptionmenu (preferences.bands);
-	/* set the menu strings for the modeoption menu */
-	makemodeoptionmenu (preferences.modes);
-
-	
 	/* either hide the editbox or the optionmenu */
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 	if (preferences.modeseditbox == 0)
@@ -370,9 +365,7 @@ main (int argc, char *argv[])
 		gtk_widget_hide (bandoptionmenu);
 
 	/* set clock appearance */
-	clocklabel = lookup_widget (mainwindow, "clocklabel");
 	clockhandlebox = lookup_widget (mainwindow, "clockhandlebox");
-	setlabelstyle (clocklabel, preferences.themecolor, preferences.themefont);
 	if (preferences.clock == 0)
 	{	/* no clock */
 		gtk_widget_hide (clockhandlebox);
@@ -383,14 +376,6 @@ main (int argc, char *argv[])
 		clocktimer = g_timeout_add (1000, (GSourceFunc) updateclock, NULL);
 	}
 
-	/* set appearance of the QSO, DXCC and locator frame */
-	dxccframe = lookup_widget (mainwindow, "dxccframe");
-	setframestyle (dxccframe, preferences.themecolor, preferences.themefont);
-	qsoframe = lookup_widget (mainwindow, "qsoframe");
-	setframestyle (qsoframe, preferences.themecolor, preferences.themefont);
-	locatorframe = lookup_widget (mainwindow, "locatorframe");
-	setframestyle (locatorframe, preferences.themecolor, preferences.themefont);
-
 	/* set up the message queue for remote data */
 #if defined(HAVE_SYS_IPC_H)
 	msgid = msgget ((key_t) 1238, 0666 | IPC_CREAT);
@@ -417,9 +402,6 @@ main (int argc, char *argv[])
 	powerlabel = lookup_widget (mainwindow, "powerlabel");
 	powerbutton = lookup_widget (mainwindow, "powerbutton");
 #if WANT_HAMLIB
-	setlabelstyle (frequencylabel, preferences.themecolor,
-		 preferences.themefont);
-
 	/* clickable buttons and events for hamlib */
 	g_signal_connect (G_OBJECT (mhzbutton), "clicked",
 					G_CALLBACK (on_mhzbutton_clicked), NULL);
@@ -432,7 +414,7 @@ main (int argc, char *argv[])
 
 	/* init rig if hamlib is enabled and show/hide some widgets */
 	if (preferences.hamlib > 0)
-		hamlibresult = start_hamlib (preferences.radio, preferences.device, 
+		hamlibresult = start_hamlib (preferences.rigid, preferences.device, 
 			RIG_DEBUG_NONE, preferences.polltime);
 
 	g_signal_connect (G_OBJECT (smeterdrawingarea), "configure_event",
