@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,8 +103,9 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 		*locatorhbox, *powerhbox, *unknown1hbox, *unknown2hbox,
 		*dateentry, *gmtentry, *callentry, *endentry, *rstentry,
 		*myrstentry, *powerentry, *nameentry, *qthentry,
-		*locatorentry, *unknownentry1, *unknownentry2, *remarksentry,
+		*locatorentry, *unknownentry1, *unknownentry2, *remtv,
 		*remarksvbox;
+	GtkTextBuffer *b;
 	gchar *temp, **remoteinfo, *argument = NULL, *remarks;
 	gint i, j = 0, bandindex, modeindex, err = 0;
 	logtype *logw;
@@ -267,7 +268,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						if (g_ascii_strcasecmp (remarks, "") == 0)
 							remarks = g_strdup (argument);
 						else
-							remarks = g_strconcat (remarks, ", ", argument, 0);
+							remarks = g_strconcat (remarks, ", ", argument, NULL);
 					}
 				}
 			}
@@ -283,7 +284,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						if (g_ascii_strcasecmp (remarks, "") == 0)
 							remarks = g_strdup (argument);
 						else
-							remarks = g_strconcat (remarks, ", ", argument, 0);
+							remarks = g_strconcat (remarks, ", ", argument, NULL);
 					}
 				}
 			}	
@@ -295,7 +296,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 					if (g_ascii_strcasecmp (remarks, "") == 0)
 						remarks = g_strdup (argument);
 					else
-					remarks = g_strconcat (remarks, ", ", argument, 0);
+					remarks = g_strconcat (remarks, ", ", argument, NULL);
 				}
 			}
 
@@ -337,7 +338,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						if (g_ascii_strcasecmp (remarks, "") == 0)
 							remarks = g_strdup (argument);
 						else
-							remarks = g_strconcat (remarks, ", ", argument, 0);
+							remarks = g_strconcat (remarks, ", ", argument, NULL);
 					}
 				}
 			}
@@ -353,7 +354,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						if (g_ascii_strcasecmp (remarks, "") == 0)
 							remarks = g_strdup (argument);
 						else
-							remarks = g_strconcat (remarks, ", ", argument, 0);
+							remarks = g_strconcat (remarks, ", ", argument, NULL);
 					}
 				}
 			}
@@ -369,7 +370,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						if (g_ascii_strcasecmp (remarks, "") == 0)
 							remarks = g_strdup (argument);
 						else
-							remarks = g_strconcat (remarks, ", ", argument, 0);
+							remarks = g_strconcat (remarks, ", ", argument, NULL);
 					}
 				}
 			}
@@ -408,7 +409,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				qso[MODE] =	gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
 		}
 	
-		if (preferences.remoteadding == 1)
+		if (preferences.remoteadding == 1 && logw)
 		{
 			qso[NR] = g_strdup_printf ("%d", ++logw->qsos);
 	
@@ -515,9 +516,10 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 			remarksvbox = lookup_widget (mainwindow, "remarksvbox");
 			if (GTK_WIDGET_VISIBLE (remarksvbox))
 			{
-				remarksentry = lookup_widget (mainwindow, "remarksentry");
+				remtv = lookup_widget (mainwindow, "remtv");
+				b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
 				if (strlen(qso[REMARKS]) > 0)
-					gtk_entry_set_text (GTK_ENTRY (remarksentry), qso[REMARKS]);
+					gtk_text_buffer_set_text (b, qso[REMARKS], -1);
 			}
 			temp = g_strdup_printf (_("Remote data received from %s (#%d)"), remote.program, ++remote.nr);
 		}
