@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@
 
 gint statusbartimer;
 extern GtkWidget *mainwindow;
+extern GtkWidget *keyerwindow;
 extern GtkWidget *b4dialog;
 extern preferencestype preferences;
 extern statetype state;
@@ -66,14 +67,8 @@ extern gint clocktimer, savetimer;
 extern glong msgid;
 extern void *shareCall;
 extern GList *logwindowlist;
-extern gchar *searchpx;
 extern GtkUIManager *ui_manager;
 
-#if WANT_HAMLIB
-extern GList *riglist;
-#endif
-
-
 /* calculate location string from latitude and longitude information,
  * returned value has to be freed */
 gchar *
@@ -111,7 +106,6 @@ makebandoptionmenu (gchar *bands)
 	gtk_widget_show (bandoptionmenu);
 	bandhbox2 = lookup_widget (mainwindow, "bandhbox2");
 	gtk_box_pack_start (GTK_BOX (bandhbox2), bandoptionmenu, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (bandoptionmenu, 130, 27);
 
 	split = g_strsplit (bands, ",", -1);
 	for (;;)
@@ -141,7 +135,6 @@ makemodeoptionmenu (gchar *modes)
 	gtk_widget_show (modeoptionmenu);
 	modehbox2 = lookup_widget (mainwindow, "modehbox2");
 	gtk_box_pack_start (GTK_BOX (modehbox2), modeoptionmenu, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (modeoptionmenu, 130, 27);
 
 	split = g_strsplit (modes, ",", -1);
 	for (;;)
@@ -214,8 +207,41 @@ freestate (void)
 static void
 freeprefs (void)
 {
+	g_free (preferences.modes);
+	g_free (preferences.bands);
+	g_free (preferences.device);
+	g_free (preferences.rigconf);
+	g_free (preferences.logfont);
 	g_free (preferences.savedir);
+	g_free (preferences.backupdir);
+	g_free (preferences.logstoload);
+	g_free (preferences.locator);
+	g_free (preferences.freefield1);
+	g_free (preferences.freefield2);
+	g_free (preferences.callsign);
+	g_free (preferences.defaultmhz);
+	g_free (preferences.defaultmode);
+	g_free (preferences.defaulttxrst);
+	g_free (preferences.defaultrxrst);
+	g_free (preferences.defaultpower);
+	g_free (preferences.defaultfreefield1);
+	g_free (preferences.defaultfreefield2);
+	g_free (preferences.defaultremarks);
 	g_free (preferences.b4columns);
+	g_free (preferences.logcwidths);
+	g_free (preferences.saveastsv);
+	g_free (preferences.cwf1);
+	g_free (preferences.cwf2);
+	g_free (preferences.cwf3);
+	g_free (preferences.cwf4);
+	g_free (preferences.cwf5);
+	g_free (preferences.cwf6);
+	g_free (preferences.cwf7);
+	g_free (preferences.cwf8);
+	g_free (preferences.cwf9);
+	g_free (preferences.cwf10);
+	g_free (preferences.cwf11);
+	g_free (preferences.cwf12);
 }
 
 /* free mem in remote struct */
@@ -230,9 +256,9 @@ void
 save_windowsize_and_cleanup (void)
 {
 	gint i;
-	GtkWidget *bandoptionmenu, *modeoptionmenu, *handlebox;
+	GtkWidget *bandoptionmenu, *modeoptionmenu, *handlebox, *hpaned;
 
-	/* free the dxcc array */
+	/* free the tables array */
 	cleanup_dxcc ();
 
 	/* free the qso array */
@@ -270,18 +296,22 @@ save_windowsize_and_cleanup (void)
 	{
 		preferences.viewb4 = 0;
 		preferences.b4x = 10;
-        preferences.b4y = 30;
-        preferences.b4width = 500;
-        preferences.b4height = 300;
+		preferences.b4y = 30;
+		preferences.b4width = 500;
+		preferences.b4height = 300;
 	}
+
+	hpaned = lookup_widget (mainwindow, "hpaned");
+	preferences.handlebarpos = gtk_paned_get_position (GTK_PANED(hpaned));
+	if (keyerwindow)
+		g_signal_emit_by_name (G_OBJECT(keyerwindow), "delete-event");
+
 	savepreferences ();
 	savehistory ();
 
 #if WANT_HAMLIB
 	if (preferences.hamlib > 0)
 		stop_hamlib ();
-	if (riglist)
-		g_list_free (riglist);
 #endif
 
 	g_free (xlogdir);
@@ -307,8 +337,6 @@ save_windowsize_and_cleanup (void)
 		}
 #endif
 
-	g_free(searchpx);
-
 	freestate ();
 	freeprefs ();
 	freeremote ();
@@ -323,18 +351,20 @@ finddot (gchar * str)
 	qsoband = g_strdup (str);
 	end = qsoband + strlen (qsoband);
 	for (j = qsoband; j < end; ++j)
+	{
+		switch (*j)
 		{
-			switch (*j)
-			{
-				case '.':
-				*j = '\0';
-				break;
-			}
+			case '.':
+			*j = '\0';
+			break;
 		}
+	}
 	if (g_ascii_strcasecmp (qsoband, "1") == 0)
 		found = "1.8";
 	else if (g_ascii_strcasecmp (qsoband, "3") == 0)
 		found = "3.5";
+	else if (g_ascii_strcasecmp (qsoband, "5") == 0)
+		found = "5.3";
 	else if (g_ascii_strcasecmp (qsoband, "7") == 0)
 		found = "7";
 	else if (g_ascii_strcasecmp (qsoband, "29") == 0)
@@ -349,11 +379,11 @@ finddot (gchar * str)
 			found = "144";
 		else if (atoi (qsoband) > 221 && atoi (qsoband) < 226)
 			found = "222";
-		else if (atoi (qsoband) > 429 && atoi (qsoband) < 440)
+		else if (atoi (qsoband) > 419 && atoi (qsoband) < 451)
 			found = "432";
 		else if (atoi (qsoband) > 901 && atoi (qsoband) < 929)
 			found = "902";
-		else if (atoi (qsoband) > 1239 && atoi (qsoband) < 1301)
+		else if (atoi (qsoband) > 1239 && atoi (qsoband) < 1326)
 			found = "1296";
 		else 
 			found = qsoband;
@@ -392,19 +422,19 @@ findband (gchar * arg)
 	fr = strtoll(arg, (char **)NULL, 10);
 
 	if (fr > 1325)		/* no dot */
-		{
-			sprintf (str, "%lld", fr);
-			if (strlen (str) > 9)
-	str[strlen (str) - 9] = '\0';
-			else if (strlen (str) > 6)
-	str[strlen (str) - 6] = '\0';
-			else if (strlen (str) > 3)
-	str[strlen (str) - 3] = '\0';
-			fr = strtoll(str, (char **)NULL, 10);
-		}
+	{
+		sprintf (str, "%lld", fr);
+		if (strlen (str) > 9)
+			str[strlen (str) - 9] = '\0';
+		else if (strlen (str) > 6)
+			str[strlen (str) - 6] = '\0';
+		else if (strlen (str) > 3)
+			str[strlen (str) - 3] = '\0';
+		fr = strtoll(str, (char **)NULL, 10);
+	}
 
 	switch (fr)
-		{
+	{
 		case 29:
 			fr = 28;
 			break;
@@ -428,7 +458,7 @@ findband (gchar * arg)
 			break;
 		default:
 			break;
-		}
+	}
 	sprintf (str, "%lld", fr);
 	return (str);
 }
@@ -510,11 +540,11 @@ updateclock (void)
 	nowdate = getdate ();
 	nowtime = gettime ();
 	clocklabel = lookup_widget (mainwindow, "clocklabel");
-	g_string_printf (timestr, "%s", nowdate);
+	g_string_printf (timestr, "<b>%s", nowdate);
 	timestr = g_string_append_c (timestr, ' ');
 	timestr = g_string_append (timestr, nowtime);
-	timestr = g_string_append (timestr, " GMT");
-	gtk_label_set_text (GTK_LABEL (clocklabel), timestr->str);
+	timestr = g_string_append (timestr, " GMT</b>");
+	gtk_label_set_markup (GTK_LABEL (clocklabel), timestr->str);
 	g_string_free (timestr, TRUE);
 	g_free (nowdate);
 	g_free (nowtime);
@@ -577,7 +607,7 @@ set_qsoframe (gpointer arg)
 	gint i, j;
 	GtkWidget *endhbox, *powerhbox, *namehbox, *locatorhbox, *qthhbox,
 		*unknown1hbox, *unknown2hbox, *powerbutton, *powerlabel, *qslhbox,
-		*locatorframe, *remarksvbox;
+		*locatorframe, *remarksvbox, *clearallmenu;
 	logtype *logw = (logtype *) arg;
 
 	endhbox = lookup_widget (mainwindow, "endhbox");
@@ -696,6 +726,9 @@ set_qsoframe (gpointer arg)
 		gtk_widget_hide (unknown2hbox);
 		gtk_widget_show (remarksvbox);
 	}
+	clearallmenu = gtk_ui_manager_get_widget
+         (ui_manager, "/MainMenu/EditMenu/Clear All");
+	g_signal_emit_by_name (G_OBJECT (clearallmenu), "activate");
 }
 
 gboolean
@@ -714,37 +747,19 @@ fileexist (gchar * path)
 		return (FALSE);
 }
 
-static gchar *
-strshift (gchar * str, size_t shift)
-{
-  gchar *start, *stop;
-
-  start = str;
-  stop = str + strlen (str);
-  memmove (start + shift, start, stop - start + 1);
-
-  return (str + shift);
-}
-
-
 gchar *
-my_strreplace (gchar * str, const gchar * from, const gchar * to)
+my_strreplace(const char *str, const char *delimiter, const char *replacement)
 {
-  gint tolen, fromlen, shift;
-  gchar *start, *stop, *p;
+	gchar **split;
+	gchar *ret;
 
-  tolen = strlen (to);
-  fromlen = strlen (from);
-  shift = tolen - fromlen;
-  start = str;
-  stop = str + strlen (str);
+	g_return_val_if_fail (str != NULL, NULL);
+	g_return_val_if_fail (delimiter != NULL, NULL);
+	g_return_val_if_fail (replacement != NULL, NULL);
 
-  while (NULL != (p = strstr (start, from)))
-    {
-      start = strshift (p + fromlen, shift);
-      stop = stop + shift;
-      memmove (p, to, tolen);
-    }
+	split = g_strsplit (str, delimiter, 0);
+	ret = g_strjoinv (replacement, split);
+	g_strfreev (split);
 
-  return str;
+	return ret;
 }
