@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,4 +41,4 @@ gchar *getlabelcolor (GtkWidget * label);
 gint autosave (void);
 void set_qsoframe (gpointer arg);
 gboolean fileexist (gchar * path);
-gchar *my_strreplace(gchar *str, const gchar *from, const gchar *to);
+gchar *my_strreplace(const char *str, const char *delimiter, const char *replacement);
